pagebotcocoa.contexts.canvas package
====================================

Submodules
----------

pagebotcocoa.contexts.canvas.canvasbuilder module
-------------------------------------------------

.. automodule:: pagebotcocoa.contexts.canvas.canvasbuilder
   :members:
   :undoc-members:
   :show-inheritance:

pagebotcocoa.contexts.canvas.canvascontext module
-------------------------------------------------

.. automodule:: pagebotcocoa.contexts.canvas.canvascontext
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: pagebotcocoa.contexts.canvas
   :members:
   :undoc-members:
   :show-inheritance:
